@@ -17,7 +17,10 @@ namespace core {
 class
     GenericObserver
 {
-
+public:
+    
+    virtual ~GenericObserver() = default;
+    
   protected:
     GenericObserver() {};
 };
